@@ -8,6 +8,10 @@ use interoptopus::{ffi_type, pattern_callback};
 use std::fmt::Debug;
 use std::marker::PhantomData;
 
+pub trait Helper {}
+
+impl Helper for u8 {}
+
 // Let's assume we can't implement `CTypeInfo` for this.
 #[repr(C)]
 pub struct SomeForeignType {
@@ -58,6 +62,15 @@ pub struct Generic3<T> {
     pub x: T,
 }
 
+#[ffi_type(opaque, name = "Generic4")]
+#[repr(C)]
+pub struct Generic4<T>
+where
+    T: Helper,
+{
+    pub x: T,
+}
+
 #[ffi_type(unsafe, skip(p))]
 #[repr(C)]
 pub struct Phantom<'a, T>
